@extends('layouts.main') 
@section('title', $user->name)
@section('content')
    <!-- push external head elements to head -->
    @push('head')
        <link rel="stylesheet" href="{{ asset('plugins/select2/dist/css/select2.min.css') }}">
        <link href='https://fonts.googleapis.com/css?family=Josefin Sans' rel='stylesheet'>
    @endpush

<?php 
    $getstatecodedata = DB::table('state_master')->get();
    $getdistrictcodedata = DB::table('district_master')->get();
?>
    
    <div class="container-fluid">
    	<div class="page-header">
            <div class="row align-items-end">
                <div class="col-lg-8">
                    <div class="page-header-title">
                        <i class="ik ik-user-plus bg-blue"></i>
                        <div class="d-inline">
                            <h5>{{ __('Edit User')}}</h5>
                            <span>{{ __('Create new user, assign roles & permissions')}}</span>
                        </div>
                    </div>
                </div>
                <div class="col-lg-4">
                    <nav class="breadcrumb-container" aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{route('dashboard')}}"><i class="ik ik-home"></i></a>
                            </li>
                            <li class="breadcrumb-item">
                                <a href="{{route('users')}}">{{ __('Users')}}</a>
                            </li>
                            <li class="breadcrumb-item">
                                <!-- clean unescaped data is to avoid potential XSS risk -->
                                {{ clean($user->name, 'titles')}}
                            </li>

                        </ol>
                    </nav>
                </div>
            </div>
        </div>
        <div class="row">
            <!-- start message area-->
            @include('include.message')
            <!-- end message area-->
            <div class="col-md-12">
                <div class="card">
                    <div class="card-body">
                        <form class="forms-sample" method="POST" action="{{ url('user/update') }}" >
                        @csrf
                            <input type="hidden" name="id" value="{{$user->id}}">
                            <div class="row">
                                <div class="col-sm-6">

                                    <div class="form-group">
                                        <label for="name">{{ __('Username')}}<span class="text-red">*</span></label>
                                        <input id="name" type="text" class="form-control @error('name') is-invalid @enderror" name="name" value="{{ clean($user->name, 'titles')}}" required>
                                        <div class="help-block with-errors"></div>

                                        @error('name')
                                            <span class="invalid-feedback" role="alert">
                                                <strong>{{ $message }}</strong>
                                            </span>
                                        @enderror
                                    </div>
                                    <div class="form-group">
                                        <label for="email">{{ __('Email')}}<span class="text-red">*</span></label>
                                        <input id="email" type="email" class="form-control @error('email') is-invalid @enderror" name="email" value="{{ clean($user->email, 'titles')}}" required>
                                        <div class="help-block with-errors"></div>

                                        @error('email')
                                            <span class="invalid-feedback" role="alert">
                                                <strong>{{ $message }}</strong>
                                            </span>
                                        @enderror
                                    </div>

                                   
                                    <div class="form-group">
                                        <label for="password">{{ __('Password')}}</label>
                                        <input id="password" type="password" class="form-control @error('password') is-invalid @enderror" name="password"  >
                                        <div class="help-block with-errors"></div>

                                        @error('password')
                                            <span class="invalid-feedback" role="alert">
                                                <strong>{{ $message }}</strong>
                                            </span>
                                        @enderror
                                    </div>
                                    <div class="form-group">
                                        <label for="password-confirm">{{ __('Confirm Password')}}</label>
                                        <input id="password-confirm" type="password" class="form-control" name="password_confirmation">
                                        <div class="help-block with-errors"></div>
                                    </div>
                                    <div class="form-group">
                                        <label for="emp_code">{{ __('Employee Code')}}</label>
                                        <input type="text" class="form-control" id="emp_code" name='emp_code' value="{{ clean($user->emp_code, 'titles')}}" placeholder="Enter Employee Code" required>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <!-- Assign role & view role permisions -->
                                    <div class="form-group">
                                        <label for="dist_code">{{ __('District Code')}}</label>
                                        <select name='dist_code'  class='form-control' value='Select Option'>
                                            <option>Select District Code</option>
                                            <?php foreach($getdistrictcodedata as $getdistrictcode){ ?>
                                             <option value='<?php echo $getdistrictcode->district_code; ?>' @if(!empty($user)){{ $user->dist_code == $getdistrictcode->district_code ? 'selected' : '' }} @endif ><?php echo $getdistrictcode->district_code; ?></option>
                                             <?php } ?>
                                        </select>
                                    </div>
                                    <div class="form-group">
                                        <label for="state_code">{{ __('State Code')}}</label>
                                        <select name='state_code'  class='form-control' value='Select Option'>
                                            <option>Select State Code</option>
                                            <?php foreach($getstatecodedata as $getstatecode){ ?>
                                             <option value='<?php echo $getstatecode->state_code; ?>' @if(!empty($user)) {{ $user->state_code == $getstatecode->state_code ? 'selected' : '' }} @endif ><?php echo $getstatecode->state_code; ?></option>
                                             <?php } ?>
                                        </select>
                                    </div>
                                    <div class="form-group">
                                        <label for="role">{{ __('Assign Role')}}<span class="text-red">*</span></label>
                                        {!! Form::select('role', $roles, $user_role->id??'' ,[ 'class'=>'form-control select2', 'placeholder' => 'Select Role','id'=> 'role', 'required'=>'required']) !!}
                                    </div>
                                    <div class="form-group">
                                        <label for="role">{{ __('Permissions')}}</label>
                                        <div id="permission" class="form-group">
                                            @foreach($user->getAllPermissions() as $key => $permission) 
                                            <span class="badge badge-dark m-1">
                                                <!-- clean unescaped data is to avoid potential XSS risk -->
                                                {{ clean($permission->name, 'titles')}}
                                            </span>
                                            @endforeach
                                        </div>
                                        <input type="hidden" id="token" name="token" value="{{ csrf_token() }}">
                                    </div>
                                </div>
                                
                                <div class="col-md-12">
                                    Permissions
                                </div>
                                <div class="col-md-12">
                                    <table class="table table-bordered p-3">
                                        <tr>
                                            <td style="width:20%">Form name</td>
                                            <td style="width:20%">Add</td>
                                            <td style="width:20%">View</td>
                                            <td style="width:20%">Modify</td>
                                            <td style="width:20%">Delete</td>
                                        </tr>
                                        <tr>
                                            <td>Client registration</td>
                                            <td>
                                                
                                                <select name='client_registration_add'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->client_registration_add) &&  $userPermisssions->client_registration_add == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->client_registration_add) &&  $userPermisssions->client_registration_add == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                            <td>
                                                <select name='client_registration_view'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->client_registration_view) &&  $userPermisssions->client_registration_view == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->client_registration_view) &&  $userPermisssions->client_registration_view == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                            <td>
                                                <select name='client_registration_edit'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->client_registration_edit) &&  $userPermisssions->client_registration_edit == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->client_registration_edit) &&  $userPermisssions->client_registration_edit == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                            <td>
                                                <select name='client_registration_delete'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->client_registration_delete) &&  $userPermisssions->client_registration_delete == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->client_registration_delete) &&  $userPermisssions->client_registration_delete == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td>Mat Intake</td>
                                            <td>
                                                <select name='mat_intake_add'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->mat_intake_add) &&  $userPermisssions->mat_intake_add == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->mat_intake_add) &&  $userPermisssions->mat_intake_add == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                            <td>
                                                <select name='mat_intake_view'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->mat_intake_view) &&  $userPermisssions->mat_intake_view == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->mat_intake_view) &&  $userPermisssions->mat_intake_view == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                            <td>
                                                <select name='mat_intake_edit'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->mat_intake_edit) &&  $userPermisssions->mat_intake_edit == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->mat_intake_edit) &&  $userPermisssions->mat_intake_edit == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                            <td>
                                                <select name='mat_intake_delete'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->mat_intake_delete) &&  $userPermisssions->mat_intake_delete == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->mat_intake_delete) &&  $userPermisssions->mat_intake_delete == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td>Mat Monthly</td>
                                            <td>
                                                <select name='mat_monthly_add'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->mat_monthly_add) &&  $userPermisssions->mat_monthly_add == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->mat_monthly_add) &&  $userPermisssions->mat_monthly_add == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                            <td>
                                                <select name='mat_monthly_view'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->mat_monthly_view) &&  $userPermisssions->mat_monthly_view == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->mat_monthly_view) &&  $userPermisssions->mat_monthly_view == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                            <td>
                                                <select name='mat_monthly_edit'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->mat_monthly_edit) &&  $userPermisssions->mat_monthly_edit == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->mat_monthly_edit) &&  $userPermisssions->mat_monthly_edit == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                            <td>
                                                <select name='mat_monthly_delete'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->mat_monthly_delete) &&  $userPermisssions->mat_monthly_delete == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->mat_monthly_delete) &&  $userPermisssions->mat_monthly_delete == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td>Daily service</td>
                                            <td>
                                                <select name='daily_service_add'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->daily_service_add) &&  $userPermisssions->daily_service_add == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->daily_service_add) &&  $userPermisssions->daily_service_add == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                            <td>
                                                <select name='daily_service_view'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->daily_service_view) &&  $userPermisssions->daily_service_view == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->daily_service_view) &&  $userPermisssions->daily_service_view == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                            <td>
                                                <select name='daily_service_edit'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->daily_service_edit) &&  $userPermisssions->daily_service_edit == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->daily_service_edit) &&  $userPermisssions->daily_service_edit == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                            <td>
                                                <select name='daily_service_delete'  class='form-control' value='Select Option'>
                                                    <option @if(isset($userPermisssions->daily_service_delete) &&  $userPermisssions->daily_service_delete == 1) selected @endif value="1">Yes</option>
                                                    <option @if(isset($userPermisssions->daily_service_delete) &&  $userPermisssions->daily_service_delete == 0) selected @endif value="0">No</option>
                                                </select>
                                            </td>
                                        </tr>
                                    </table>
                                </div>

                                <div class="col-md-12">
                                    <div class="form-group">
                                        <button type="submit" class="btn btn-primary form-control-right">{{ __('Update')}}</button>
                                    </div>
                                </div>
                            </div>
                        
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- push external js -->
    @push('script') 
        <script src="{{ asset('plugins/select2/dist/js/select2.min.js') }}"></script>
        <!--get role wise permissiom ajax script-->
        <script src="{{ asset('js/get-role.js') }}"></script>
    @endpush
@endsection
