<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Auth\LoginController;
use App\Http\Controllers\Auth\RegisterController;
use App\Http\Controllers\Auth\ForgotPasswordController;
use App\Http\Controllers\Auth\ResetPasswordController;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\RolesController;
use App\Http\Controllers\PermissionController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/ 
Route::get('/', function () { return view('home'); });
Route::get('/foo', function () {
    Artisan::call('storage:link');
});

Route::get('login', [LoginController::class,'showLoginForm'])->name('login');
Route::post('login', [LoginController::class,'login']);
Route::post('register', [RegisterController::class,'register']);

Route::get('password/forget',  function () { 
	return view('pages.forgot-password'); 
})->name('password.forget');
Route::post('password/email', [ForgotPasswordController::class,'sendResetLinkEmail'])->name('password.email');
Route::get('password/reset/{token}', [ResetPasswordController::class,'showResetForm'])->name('password.reset');
Route::post('password/reset', [ResetPasswordController::class,'reset'])->name('password.update');


Route::group(['middleware' => 'auth'], function(){
	// logout route
	Route::get('/logout', [LoginController::class,'logout']);
	Route::get('/clear-cache', [HomeController::class,'clearCache']);

	// dashboard route  
	Route::get('/dashboard', [HomeController::class,'dashboard'])->name('dashboard');
	Route::get('/user_logs', [HomeController::class,'user_logs'])->name('user_logs');
	Route::get('/non_ti_report', [HomeController::class,'non_ti_report'])->name('non_ti_report');

	//only those have manage_user permission will get access
	Route::group(['middleware' => 'can:manage_user'], function(){
	Route::get('/users', [UserController::class,'index'])->name('users');
	Route::get('/user/get-list', [UserController::class,'getUserList']);
		Route::get('/user/create', [UserController::class,'create']);
		Route::post('/user/create', [UserController::class,'store'])->name('create-user');
		Route::get('/user/{id}', [UserController::class,'edit']);
		Route::post('/user/update', [UserController::class,'update']);
		Route::post('/user/edit-profile', [UserController::class,'edit_user_profile'])->name('edit_user_profile');
		Route::get('/user/delete/{id}', [UserController::class,'delete']);
	});

	//only those have manage_role permission will get access
	Route::group(['middleware' => 'can:manage_role|manage_user'], function(){
		Route::get('/roles', [RolesController::class,'index']);
		Route::get('/role/get-list', [RolesController::class,'getRoleList']);
		Route::post('/role/create', [RolesController::class,'create']);
		Route::get('/role/edit/{id}', [RolesController::class,'edit']);
		Route::post('/role/update', [RolesController::class,'update']);
		Route::get('/role/delete/{id}', [RolesController::class,'delete']);
	});


	//only those have manage_permission permission will get access
	Route::group(['middleware' => 'can:manage_permission|manage_user'], function(){
		Route::get('/permission', [PermissionController::class,'index']);
		Route::get('/permission/get-list', [PermissionController::class,'getPermissionList']);
		Route::post('/permission/create', [PermissionController::class,'create']);
		Route::get('/permission/update', [PermissionController::class,'update']);
		Route::get('/permission/delete/{id}', [PermissionController::class,'delete']);
	});

	// get permissions
	Route::get('/get-role-permissions-badge', [PermissionController::class,'getPermissionBadgeByRole']);


	// permission examples
    Route::get('/permission-example', function () {
    	return view('permission-example'); 
    });
    // API Documentation
    Route::get('/rest-api', function () { return view('api'); });
    // Editable Datatable
	Route::get('/table-datatable-edit', function () { 
		return view('pages.datatable-editable'); 
	});

    // Themekit demo pages
    
    //new routes by monty - 07-07-2021
    
    Route::get('/client-register-2', function () { return view('pages.client-register-2'); });
    Route::get('/client-register', function () { return view('pages.client-register'); });
    Route::get('/user-login', function () { return view('pages.user-login'); });
    Route::get('/state-master', function () { return view('pages.state-master'); });
    Route::get('/district-master', function () { return view('pages.district-master'); });
    Route::get('/employee-master', function () { return view('pages.employee-master'); });
    Route::get('/question-answer', function () { return view('pages.question-answer'); });
    Route::get('/artcenter-master', function () { return view('pages.artcenter-master'); });
    Route::get('/subtypology-master', function () { return view('pages.subtypology-master'); });
    Route::get('/mat-form', function () { return view('pages.mat-form'); });
    
    Route::get('/mat-form-monthly', function () { return view('pages.mat-form-monthly'); });
    
    Route::get('/daily-service', function () { return view('pages.daily-service'); });
    
	Route::get('/calendar', function () { return view('pages.calendar'); });
	Route::get('/charts-amcharts', function () { return view('pages.charts-amcharts'); });
	Route::get('/charts-chartist', function () { return view('pages.charts-chartist'); });
	Route::get('/charts-flot', function () { return view('pages.charts-flot'); });
	Route::get('/charts-knob', function () { return view('pages.charts-knob'); });
	Route::get('/forgot-password', function () { return view('pages.forgot-password'); });
	Route::get('/form-addon', function () { return view('pages.form-addon'); });
	Route::get('/form-advance', function () { return view('pages.form-advance'); });
	Route::get('/form-components', function () { return view('pages.form-components'); });
	Route::get('/form-picker', function () { return view('pages.form-picker'); });
	Route::get('/invoice', function () { return view('pages.invoice'); });
	Route::get('/layout-edit-item', function () { return view('pages.layout-edit-item'); });
	Route::get('/layouts', function () { return view('pages.layouts'); });

	Route::get('/navbar', function () { return view('pages.navbar'); });
	Route::get('/profile', function () { return view('pages.profile'); });
	Route::get('/project', function () { return view('pages.project'); });
	Route::get('/view', function () { return view('pages.view'); });

	Route::get('/table-bootstrap', function () { return view('pages.table-bootstrap'); });
	Route::get('/table-datatable', function () { return view('pages.table-datatable'); });
	Route::get('/taskboard', function () { return view('pages.taskboard'); });
	Route::get('/widget-chart', function () { return view('pages.widget-chart'); });
	Route::get('/widget-data', function () { return view('pages.widget-data'); });
	Route::get('/widget-statistic', function () { return view('pages.widget-statistic'); });
	Route::get('/widgets', function () { return view('pages.widgets'); });

	// themekit ui pages
	Route::get('/alerts', function () { return view('pages.ui.alerts'); });
	Route::get('/badges', function () { return view('pages.ui.badges'); });
	Route::get('/buttons', function () { return view('pages.ui.buttons'); });
	Route::get('/cards', function () { return view('pages.ui.cards'); });
	Route::get('/carousel', function () { return view('pages.ui.carousel'); });
	Route::get('/icons', function () { return view('pages.ui.icons'); });
	Route::get('/modals', function () { return view('pages.ui.modals'); });
	Route::get('/navigation', function () { return view('pages.ui.navigation'); });
	Route::get('/notifications', function () { return view('pages.ui.notifications'); });
	Route::get('/range-slider', function () { return view('pages.ui.range-slider'); });
	Route::get('/rating', function () { return view('pages.ui.rating'); });
	Route::get('/session-timeout', function () { return view('pages.ui.session-timeout'); });
	Route::get('/pricing', function () { return view('pages.pricing'); });
});


Route::get('/register', function () { return view('pages.register'); });
Route::get('/login-1', function () { return view('pages.login'); });

Route::post("/loginregclient", "HomeController@insertregform");
Route::get('/client-register-data', "HomeController@getclientregisterpending");
Route::get('/client-register-data-success', "HomeController@getclientregistersuccess");
Route::get('/deleteclientregister/{id}', "HomeController@deleteclientregister");
Route::get('editclientregister/{id}', "HomeController@showclientregister");
Route::post('/updateclientregister', "HomeController@updateclientregisterpending");
Route::post('/updateclientregistersuccess', "HomeController@updateclientregistersuccess");
Route::post('/checkmobile', 'HomeController@checkMobile');
Route::post('/checkmatmonthly', 'HomeController@checkmatmonthly');
Route::post('/getserialnumber', "HomeController@getSerialNumber");
Route::post('/getuidnumberdata', "HomeController@getUIDNumberData");
Route::post('/getsubcatdata', "HomeController@getSubCatdata");

Route::post("/statemasterinsert", "StateController@insertstate");
Route::get('/state-master-data', "StateController@getstate");
Route::get('/deletestate/{id}', "StateController@deletestate");
Route::get('editstate/{id}', "StateController@showstate");
Route::post('/updatestate', "StateController@updatestate");
Route::post('/basedOnfilter', "StateController@basedOnfilter");


Route::post("/districtinsert", "DistrictController@insertdistrict");
Route::get('/district-master-data', "DistrictController@getdistrict");
Route::get('/deletedistrict/{id}', "DistrictController@deletedistrict");
Route::get('editdistrict/{id}', "DistrictController@showdistrict");
Route::post('/updatedistrict', "DistrictController@updatedistrict");

Route::post("/employeeinsert", "EmployeeController@insertemployee");
Route::get('/employee-master-data', "EmployeeController@getemployee");
Route::get('/deleteemployee/{id}', "EmployeeController@deleteemployee");
Route::get('editemployee/{id}', "EmployeeController@showemployee");
Route::post('/updateemployee', "EmployeeController@updateemployee");

Route::post("/questionansinsert", "QuestionController@questionansinsert");
Route::get('/question-answer-data', "QuestionController@getquestion");
Route::get('/deletequestion/{id}', "QuestionController@deletequestion");
Route::get('editquestion/{id}', "QuestionController@showquestion");
Route::post('/updatequestion', "QuestionController@updatequestion");

Route::post("/userlogininsert", "UserLoginController@insertuserlogin");
Route::get('/user-login-data', "UserLoginController@getuserlogin");
Route::get('/deleteuserlogin/{id}', "UserLoginController@deleteuserlogin");
Route::get('edituserlogin/{id}', "UserLoginController@showuserlogin");
Route::post('/updateuserlogin', "UserLoginController@updateuserlogin");


Route::post("/subtypologyinsert", "SubTypologyController@insertsubtypology");
Route::get('/subtypology-master-data', "SubTypologyController@getsubtypology");
Route::get('/deletesubtypology/{id}', "SubTypologyController@deletesubtypology");
Route::get('editsubtypology/{id}', "SubTypologyController@showsubtypology");
Route::post('/updatesubtypology', "SubTypologyController@updatesubtypology");

Route::post("/artcenterinsert", "ArtCenterController@insertartcenter");
Route::get('/artcenter-master-data', "ArtCenterController@getartcenter");
Route::get('/deleteartcenter/{id}', "ArtCenterController@deleteartcenter");
Route::get('editartcenter/{id}', "ArtCenterController@showartcenter");
Route::post('/updateartcenter', "ArtCenterController@updateartcenter");


Route::post("/matinsert", "MatformController@insertmat");
Route::get('/mat-form-data', "MatformController@getmat");
Route::get('/deletemat/{id}', "MatformController@deletemat");
Route::get('editmat/{id}', "MatformController@showmat");
Route::post('/updatemat', "MatformController@updatemat");
Route::post('/getuidmatdata', "MatformController@getUidMatData");


Route::post("/matmonthlyinsert", "MatformMonthlyController@insertmatmonthly");
Route::get('/mat-form-monthly-data', "MatformMonthlyController@getmatmonthly");
Route::get('/deletematmonthly/{id}', "MatformMonthlyController@deletematmonthly");
Route::get('editmatmonthly/{id}', "MatformMonthlyController@showmatmonthly");
Route::post('/updatematmonthly', "MatformMonthlyController@updatematmonthly");


Route::post("/dailyserviceinsert", "DailyServiceController@insertdailyservice");
Route::get('/daily-service-data', "DailyServiceController@getdailyservice");
Route::get('/deletedailyservice/{id}', "DailyServiceController@deletedailyservice");
Route::get('editdailyservice/{id}', "DailyServiceController@showdailyservice");
Route::post('/updatedailyservice', "DailyServiceController@updatedailyservice");



